@@ -44,12 +44,15 @@ const _SUSHI_DBUS_PATH = '/org/gnome/NautilusPreviewer';
 const SushiIface = {
     name: 'org.gnome.NautilusPreviewer',
 
-    methods: [ { name: "activate",
+    methods: [ { name: "Activate",
                  inSignature: '',
                  outSignature: '' },
                { name: "ShowFile",
                  inSignature: 'sib',
-                 outSignature: '' } ],
+                 outSignature: '' },
+               { name: "Close",
+                 inSignature: '',
+                 outSignature: '' }],
 
     signals: [],
     properties: []
@@ -91,7 +94,7 @@ Application.prototype = {
 
     _onNameNotAcquired : function() {
         let remoteApp = new RemoteApplication();
-        remoteApp.activateRemote();
+        remoteApp.ActivateRemote();
 
         this.quit();
     },
@@ -112,7 +115,11 @@ Application.prototype = {
         settings.gtk_application_prefer_dark_theme = true;
     },
 
-    activate : function() {
+    Activate : function() {
+    },
+
+    Close: function() {
+        this.quit();
     },
 
     ShowFile : function(uri, xid, closeIfAlreadyShown) {
